@@ -107,7 +107,7 @@ END
       }
    }
    my $lr_release=$main::aws->{Liferay_Release};
-   $lr_release=~/liferay-portal-(.*)-ce-(.*)$/;
+   $lr_release=~/liferay.*portal-(.*)-(?:ce-)?(.*)$/;
    my $rnum=$1;my $rtyp=$2;
    print "   Downloading Liferay.com SQL files . . .\n";
    ($stdout,$stderr)=$handle->cmd("wget -qO- ".
